@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.ppolicy - classes for Password Policy controls
 (see https://tools.ietf.org/html/draft-behera-ldap-password-policy)
@@ -8,7 +8,7 @@ ldap0.controls.ppolicy - classes for Password Policy controls
 from pyasn1.type import tag, namedtype, namedval, univ, constraint
 from pyasn1.codec.ber import decoder
 
-from . import ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import ResponseControl
 from .simple import ValueLessRequestControl
 
 
@@ -92,5 +92,3 @@ class PasswordPolicyControl(ValueLessRequestControl, ResponseControl):
             self.error = int(error)
         else:
             self.error = None
-
-KNOWN_RESPONSE_CONTROLS.reg(PasswordPolicyControl)
