@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.ldapobject - wrapper classes above _libldap0.LDAPObject
 """
@@ -25,10 +25,10 @@ from .res import SearchResultEntry, LDAPResult
 from .lock import LDAPLock
 from .functions import _libldap0_function_call
 from .schema.subentry import SCHEMA_ATTRS
-from .controls import decode_response_ctrls, encode_request_ctrls
 from .controls.openldap import SearchNoOpControl
 from .controls.ppolicy import PasswordPolicyControl
-from .extop import ExtendedRequest, ExtendedResponse, EXTOP_RESPONSE_REGISTRY
+from .res import encode_request_ctrls, decode_response_ctrls
+from .extop import ExtendedRequest, ExtendedResponse
 from .extop.dds import RefreshRequest, RefreshResponse
 from .extop.whoami import WhoAmIRequest, WhoAmIResponse
 from .extop.passmod import PassmodRequest, PassmodResponse
@@ -542,8 +542,6 @@ class LDAPObject:
             False,
             True,
         )
-        if extop_resp_class is None:
-            extop_resp_class = EXTOP_RESPONSE_REGISTRY.get(respoid)
         if extop_resp_class is None:
             extop_response = ExtendedResponse(encodedResponseValue=respvalue)
         else:
